/**
 * Returns a function for performing column and/or row-level security on an array of objects.
 *
 * @param data The original dataset to apply column and/or row-level security to.
 * @param security The predicate functions for column and row-level security.
 * @returns A function that can filter the original dataset given a provided context.
 */
declare function export_default<T extends object, U = unknown>(data: T[], security?: {
    row?: (row: T, context: U) => boolean;
    column?: (row: T, context: U) => Set<keyof T> | true;
}): (context: U) => Partial<T>[];

export { export_default as default };
